@@ -5,7 +5,7 @@ package Apache::SWIT::Maker::Conversions;
 use base 'Exporter';
 
 our @EXPORT = qw(conv_table_to_class conv_make_full_class
-		conv_next_dual_test);
+		conv_next_dual_test conv_class_to_app_name);
 
 sub _capitalize {
 	my ($l, $rest) = ($_[0] =~ /(\w)(\w*)/);
@@ -38,4 +38,10 @@ sub conv_next_dual_test {
 	return sprintf("%03d", $max + 10);
 }
 
+sub conv_class_to_app_name {
+	my $class = lc(shift);
+	$class =~ s/::/_/g;
+	return $class;
+}
+
 1;
